@@ -1,16 +1,33 @@
 use num_bigint::BigInt;
+use pyo3::exceptions::PyValueError;
 use pyo3::intern;
 use pyo3::prelude::*;
-use pyo3::types::PyDict;
+use pyo3::types::{PyDict, PyString};
 use pyo3::IntoPyObjectExt;
 
 use crate::build_tools::is_strict;
 use crate::errors::{ErrorType, ValError, ValResult};
 use crate::input::{Input, Int};
-use crate::tools::SchemaDict;
 
 use super::{BuildValidator, CombinedValidator, DefinitionsBuilder, ValidationState, Validator};
 
+fn validate_as_int(schema: &Bound<'_, PyDict>, key: &Bound<'_, PyString>) -> PyResult<Option<Int>> {
+    match schema.get_item(key)? {
+        Some(value) => match value.validate_int(false) {
+            Ok(v) => match v.into_inner().as_int() {
+                Ok(v) => Ok(Some(v)),
+                Err(_) => Err(PyValueError::new_err(format!(
+                    "'{key}' must be coercible to an integer"
+                ))),
+            },
+            Err(_) => Err(PyValueError::new_err(format!(
+                "'{key}' must be coercible to an integer"
+            ))),
+        },
+        None => Ok(None),
+    }
+}
+
 #[derive(Debug, Clone)]
 pub struct IntValidator {
     strict: bool,
@@ -70,6 +87,21 @@ pub struct ConstrainedIntValidator {
     gt: Option<Int>,
 }
 
+impl ConstrainedIntValidator {
+    fn build(schema: &Bound<'_, PyDict>, config: Option<&Bound<'_, PyDict>>) -> PyResult<CombinedValidator> {
+        let py = schema.py();
+        Ok(Self {
+            strict: is_strict(schema, config)?,
+            multiple_of: validate_as_int(schema, intern!(py, "multiple_of"))?,
+            le: validate_as_int(schema, intern!(py, "le"))?,
+            lt: validate_as_int(schema, intern!(py, "lt"))?,
+            ge: validate_as_int(schema, intern!(py, "ge"))?,
+            gt: validate_as_int(schema, intern!(py, "gt"))?,
+        }
+        .into())
+    }
+}
+
 impl_py_gc_traverse!(ConstrainedIntValidator {});
 
 impl Validator for ConstrainedIntValidator {
@@ -144,18 +176,3 @@ impl Validator for ConstrainedIntValidator {
         "constrained-int"
     }
 }
-
-impl ConstrainedIntValidator {
-    fn build(schema: &Bound<'_, PyDict>, config: Option<&Bound<'_, PyDict>>) -> PyResult<CombinedValidator> {
-        let py = schema.py();
-        Ok(Self {
-            strict: is_strict(schema, config)?,
-            multiple_of: schema.get_as(intern!(py, "multiple_of"))?,
-            le: schema.get_as(intern!(py, "le"))?,
-            lt: schema.get_as(intern!(py, "lt"))?,
-            ge: schema.get_as(intern!(py, "ge"))?,
-            gt: schema.get_as(intern!(py, "gt"))?,
-        }
-        .into())
-    }
-}
